==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/include/advance/WSCobjectBox.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCOBJECTBOX_H
#define WSCOBJECTBOX_H

#include <WScom.h>
#include <WSCbaseDialog.h>

class WSCscrForm;
class WSCvbtn;
class WSCvlabel;
class WSCform;
class WSCvlabel;
class WSCoption;
class WSCbaseDialog;
class WSCvtoggle;
class WSCvifield;
class WSCindexForm;

class WSCobjectBox  :public WSCbaseDialog {

  private:
     char* _file_name;
     WSCindexVariantData _req_lib_by_obj;
  protected:
     WSMFpropertyDef( WSNfileName,    char*,      _file_name ); 

     WSClistData _label_list;

     WSCvbtn*     _set_btn;

     WSCvlabel*    _class_text;
     WSCindexForm* _index;
     WSClistData  _areas;
     WSCform*     _form;
     long          _visible_lbs;
     WSClistData  _added;

     void _adjust();

static void _set_btn_work(WSCbase*);
static void _label_in_work(WSCbase*);
static void _label_out_work(WSCbase*);

//virtual void onVisibleChange(WSCbool);
//virtual void onParentVisibleChange(WSCbool);
virtual void onResize(WSCrect*);

  public:
    WSCobjectBox(WSCbase*,char*);
    virtual ~WSCobjectBox();
    virtual  long initialize();
    void  addItems(WSCstring*);
    void  delItems(WSCstring*);
    void  clearItems();
    void updateList();
    virtual void onGuiPolicyChange(long);
    WSCstring getRequiredLibrary(char* classname);
    void resetRequiredLibrary();

    WSMFguiClassDef(WSCobjectBox,WSCbaseDialog);

};


#endif //WSCTOOLBOX_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/advance/WSCobjectBox.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCOBJECTBOX_H
#define WSCOBJECTBOX_H

#include <WScom.h>
#include <WSCbaseDialog.h>

class WSCscrForm;
class WSCvbtn;
class WSCvlabel;
class WSCform;
class WSCvlabel;
class WSCoption;
class WSCbaseDialog;
class WSCvtoggle;
class WSCvifield;
class WSCindexForm;

class WSCobjectBox  :public WSCbaseDialog {

  private:
     char* _file_name;
     WSCindexVariantData _req_lib_by_obj;
  protected:
     WSMFpropertyDef( WSNfileName,    char*,      _file_name ); 

     WSClistData _label_list;

     WSCvbtn*     _set_btn;

     WSCvlabel*    _class_text;
     WSCindexForm* _index;
     WSClistData  _areas;
     WSCform*     _form;
     long          _visible_lbs;
     WSClistData  _added;

     WSDLEX32 void _adjust();

WSDLEX32 static void _set_btn_work(WSCbase*);
WSDLEX32 static void _label_in_work(WSCbase*);
WSDLEX32 static void _label_out_work(WSCbase*);

//virtual void onVisibleChange(WSCbool);
//virtual void onParentVisibleChange(WSCbool);
WSDLEX32 virtual void onResize(WSCrect*);

  public:
    WSDLEX32 WSCobjectBox(WSCbase*,char*);
    WSDLEX32 virtual ~WSCobjectBox();
    WSDLEX32 virtual  long initialize();
    WSDLEX32 void  addItems(WSCstring*);
    WSDLEX32 void  delItems(WSCstring*);
    WSDLEX32 void  clearItems();
    WSDLEX32 void updateList();
    WSDLEX32 virtual void onGuiPolicyChange(long);
    WSDLEX32 WSCstring getRequiredLibrary(char* classname);
    WSDLEX32 void resetRequiredLibrary();

    WSMFguiClassDef(WSCobjectBox,WSCbaseDialog);

};


#endif //WSCTOOLBOX_H
